/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc. and/or its affiliates, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hibernate.validator.internal.util.privilegedactions;

import java.net.URL;
import java.security.PrivilegedExceptionAction;

import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;

import org.xml.sax.SAXException;

/**
 * Loads a given XML schema.
 *
 * @author Gunnar Morling
 */
public final class NewSchema implements PrivilegedExceptionAction<Schema> {

	private final SchemaFactory schemaFactory;
	private final URL url;

	public static NewSchema action(SchemaFactory schemaFactory, URL url) {
		return new NewSchema( schemaFactory, url );
	}

	public NewSchema(SchemaFactory schemaFactory, URL url) {
		this.schemaFactory = schemaFactory;
		this.url = url;
	}

	@Override
	public Schema run() throws SAXException {
		return schemaFactory.newSchema( url );
	}
}
